@@ -3,7 +3,7 @@ import torch.nn as nn
 import torch.nn.functional as F
 import torch.optim as optim
 import math
-from utils import FeaturesHandler, PlotUtilities # pylint: disable=import-error
+from aiopslibs.utils import FeaturesHandler, PlotUtilities
 
 class SimpleTextClassifier(nn.Module):  # inherit pytorch's nn.Module
     """Text Classifier with 1 hidden layer 
